.. _reporting-bugs:

**********************
Reporting Bugs in Grok
**********************

Grok aims to become a mature framework and tries to earn reputation
for stability.  In order to maintain this reputation, the developers
would like to know of any deficiencies you find in Grok.

If you find errors in the documentation, you can correct it yourself
on the Grok website http://grok.zope.org/ . You only need to register
with the website for that, which is necessary to block spammers. On
some pages you then can use the "Add a comment" feature of the
relevant page.

All other bug reports should be submitted via the Grok Bug Tracker
(https://bugs.launchpad.net/grok/).  The bug tracker offers a Web form
which allows pertinent information to be entered and submitted to the
developers.

The first step in filing a report is to determine whether the problem
has already been reported.  The advantage in doing so, aside from
saving the developers time, is that you learn what has been done to
fix it; it may be that the problem has already been fixed for the next
release, or additional information is needed (in which case you are
welcome to provide it if you can!).  To do this, search the bug
database using the search box on the top of the page or by clicking on
"List all open bugs".

If the problem you're reporting is not already in the bug tracker, go
back to the Grok Bug Tracker and click the red "Report a bug" box on
the right. If you don't already have a launchpad account, you will be
asked to complete the registration by giving an e-mail address and
following the steps mailed to you. Complete the registration process.
Otherwise, if you're not logged in, enter your credentials and select
"Log In".  It is not possible to submit a bug report anonymously.

Being now logged in, you can submit a bug.  You will be asked a number
of questions. 

For the "Summary" field, enter a *very* short description of the
problem; less than ten words is good.  In the "Further Information"
field, describe your problem as accurate as possible. A good
description will enables the developers to reproduce your
problem. Name also the version of grok/grokproject you used.

Each bug report will be assigned to a developer who will determine
what needs to be done to correct the problem. You will receive an
update each time action is taken on the bug.

.. seealso::

   `How to Report Bugs Effectively
   <http://www.chiark.greenend.org.uk/~sgtatham/bugs.html>`_ Article
   which goes into some detail about how to create a useful bug
   report. This describes what kind of information is useful and why
   it is useful.

   `Bug Writing Guidelines
   <http://www.mozilla.org/quality/bug-writing-guidelines.html>`_
   Information about writing a good bug report.  Some of this is
   specific to the Mozilla project, but describes general good
   practices.
